/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface SynchronizationSecretConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/2.51.0/docs/resources/synchronization_secret#id SynchronizationSecret#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The object ID of the service principal for which this synchronization secret should be created
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/2.51.0/docs/resources/synchronization_secret#service_principal_id SynchronizationSecret#service_principal_id}
    */
    readonly servicePrincipalId: string;
    /**
    * credential block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/2.51.0/docs/resources/synchronization_secret#credential SynchronizationSecret#credential}
    */
    readonly credential?: SynchronizationSecretCredential[] | cdktf.IResolvable;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/2.51.0/docs/resources/synchronization_secret#timeouts SynchronizationSecret#timeouts}
    */
    readonly timeouts?: SynchronizationSecretTimeouts;
}
export interface SynchronizationSecretCredential {
    /**
    * Name for this key-value pair.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/2.51.0/docs/resources/synchronization_secret#key SynchronizationSecret#key}
    */
    readonly key: string;
    /**
    * Value for this key-value pair.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/2.51.0/docs/resources/synchronization_secret#value SynchronizationSecret#value}
    */
    readonly value: string;
}
export declare function synchronizationSecretCredentialToTerraform(struct?: SynchronizationSecretCredential | cdktf.IResolvable): any;
export declare function synchronizationSecretCredentialToHclTerraform(struct?: SynchronizationSecretCredential | cdktf.IResolvable): any;
export declare class SynchronizationSecretCredentialOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): SynchronizationSecretCredential | cdktf.IResolvable | undefined;
    set internalValue(value: SynchronizationSecretCredential | cdktf.IResolvable | undefined);
    private _key?;
    get key(): string;
    set key(value: string);
    get keyInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    get valueInput(): string | undefined;
}
export declare class SynchronizationSecretCredentialList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: SynchronizationSecretCredential[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): SynchronizationSecretCredentialOutputReference;
}
export interface SynchronizationSecretTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/2.51.0/docs/resources/synchronization_secret#create SynchronizationSecret#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/2.51.0/docs/resources/synchronization_secret#delete SynchronizationSecret#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/2.51.0/docs/resources/synchronization_secret#read SynchronizationSecret#read}
    */
    readonly read?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azuread/2.51.0/docs/resources/synchronization_secret#update SynchronizationSecret#update}
    */
    readonly update?: string;
}
export declare function synchronizationSecretTimeoutsToTerraform(struct?: SynchronizationSecretTimeouts | cdktf.IResolvable): any;
export declare function synchronizationSecretTimeoutsToHclTerraform(struct?: SynchronizationSecretTimeouts | cdktf.IResolvable): any;
export declare class SynchronizationSecretTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): SynchronizationSecretTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: SynchronizationSecretTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _read?;
    get read(): string;
    set read(value: string);
    resetRead(): void;
    get readInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/azuread/2.51.0/docs/resources/synchronization_secret azuread_synchronization_secret}
*/
export declare class SynchronizationSecret extends cdktf.TerraformResource {
    static readonly tfResourceType = "azuread_synchronization_secret";
    /**
    * Generates CDKTF code for importing a SynchronizationSecret resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the SynchronizationSecret to import
    * @param importFromId The id of the existing SynchronizationSecret that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/azuread/2.51.0/docs/resources/synchronization_secret#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the SynchronizationSecret to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/azuread/2.51.0/docs/resources/synchronization_secret azuread_synchronization_secret} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options SynchronizationSecretConfig
    */
    constructor(scope: Construct, id: string, config: SynchronizationSecretConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _servicePrincipalId?;
    get servicePrincipalId(): string;
    set servicePrincipalId(value: string);
    get servicePrincipalIdInput(): string | undefined;
    private _credential;
    get credential(): SynchronizationSecretCredentialList;
    putCredential(value: SynchronizationSecretCredential[] | cdktf.IResolvable): void;
    resetCredential(): void;
    get credentialInput(): cdktf.IResolvable | SynchronizationSecretCredential[] | undefined;
    private _timeouts;
    get timeouts(): SynchronizationSecretTimeoutsOutputReference;
    putTimeouts(value: SynchronizationSecretTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | SynchronizationSecretTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
